@@ -28,7 +28,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 /* #define UNIPLUS */
 /* #define USG5 */
 #define USG
-#define BSD
+/* #define BSD */
 #define LINUX
 
 /* SYSTEM_TYPE should indicate the kind of system you are using.
@@ -42,7 +42,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
    Define INTERRUPT_INPUT to make interrupt_input = 1 the default (use SIGIO)
 
    SIGIO can be used only on systems that implement it (4.2 and 4.3).
-   CBREAK mode has two disadvatages
+   CBREAK mode has two disadvantages
      1) At least in 4.2, it is impossible to handle the Meta key properly.
         I hear that in system V this problem does not exist.
      2) Control-G causes output to be discarded.
@@ -131,6 +131,21 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
    your system and must be used only through an encapsulation
    (Which you should place, by convention, in sysdep.c).  */
 
+/* On POSIX systems the system calls are interruptible by signals
+ that the user program has elected to catch.  Thus the system call
+ must be retried in these cases.  To handle this without massive
+ changes in the source code, we remap the standard system call names
+ to names for our own functions in sysdep.c that do the system call
+ with retries. */
+
+#define read sys_read
+#define write sys_write
+#define open sys_open
+#define close sys_close
+
+#define INTERRUPTIBLE_OPEN
+#define INTERRUPTIBLE_CLOSE
+#define INTERRUPTIBLE_IO
 
 /* If you mount the proc file system somewhere other than /proc
    you will have to uncomment the following and make the proper
@@ -152,28 +167,31 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #ifdef emacs
 #include <signal.h>
 #undef SIGIO
+#undef signal
+#define signal sys_signal
+#include <values.h>
 #endif
 
 #define HAVE_SETSID
 
 /* This is needed for sysdep.c */
 
-#define HAVE_UNISTD_H	      /* for getpagesize.h */
 #define NO_SIOCTL_H           /* don't have sioctl.h */
 
+#if 0 /* autoconf should take care of this.  */
+#define HAVE_UNISTD_H	      /* for getpagesize.h */
 #define HAVE_RANDOM           /* is builtin */
-#define HAVE_CLOSEDIR
+#endif
 #define HAVE_GETPAGESIZE
 #define HAVE_VFORK
 #define HAVE_SYS_SIGLIST
 #define HAVE_GETWD            /* cure conflict with getcwd? */
-#define HAVE_TCATTR	      /* faith@cs.unc.edu says this is needed.  */
 
 #define USE_UTIME             /* don't have utimes */
 #define SYSV_SYSTEM_DIR       /* use dirent.h */
 #define USG_SYS_TIME          /* use sys/time.h, not time.h */
 
-#define POSIX                 /* affects only getpagesize.h */
+#define POSIX                 /* affects getpagesize.h and systty.h */
 #define POSIX_SIGNALS
 
 /* libc-linux/sysdeps/linux/i386/ulimit.c says that due to shared library, */
@@ -184,6 +202,27 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #define LIBS_DEBUG
 #define LIBS_TERMCAP -ltermcap -lcurses /* save some space with shared libs*/
 #define LIB_STANDARD -lc /* avoid -lPW */
+#define C_OPTIMIZE_SWITCH /* configure can guess this just fine */
 #ifdef HAVE_X11
 #define LD_SWITCH_SYSTEM -L/usr/X386/lib
 #endif
+
+/* Let's try this out, just in case.
+   Nah.  Rik Faith <faith@cs.unc.edu> says it doesn't work well.  */
+/* #define SIGNALS_VIA_CHARACTERS */
+
+/* Rob Malouf <malouf@csli.stanford.edu> says:
+   SYSV IPC is standard a standard part of Linux since version 0.99pl10,
+   and is a very common addition to previous versions.  */
+
+#ifdef TERM
+#define LIBS_MACHINE -lclient
+#define C_SWITCH_SYSTEM -D_BSD_SOURCE -I/usr/src/term
+#else
+/* alane@wozzle.linet.org says that -lipc is not a separate library,
+   since libc-4.4.1.  So -lipc was deleted.  */
+#define LIBS_MACHINE
+#define C_SWITCH_SYSTEM -D_BSD_SOURCE
+#endif
+
+#define HAVE_SYSVIPC
